package com.despark.tuning3d.view.components.core {
    import com.despark.tuning3d.model.core.UIColors;
    import com.despark.tuning3d.view.components.gallery.GalleryLabelFactory;
    import com.despark.tuning3d.view.components.garage.DropToggleDownButton;

    import feathers.controls.Radio;
    import feathers.controls.ToggleButton;
    import feathers.layout.HorizontalAlign;

    import starling.display.Image;
    import starling.display.Quad;

    public class ScreenComponentFactory {
    public static function createDropDownButton(texture:String, name:String, iconHeight:Number = 0, colorizeIcon:Boolean = true):ToggleButton{
        var toggleButton:DropToggleDownButton;
        var defaultIcon:Image;
        var selectedIcon:Image;
        var defaultSkin:Quad;
        var selectedSkin:Quad;


        toggleButton = new DropToggleDownButton();
        toggleButton.name = name;
        defaultIcon = new Image(ButtonFactory.assetManager.getTexture(texture));
        defaultIcon.scale = ButtonFactory.assetManager.scaleFactor/2;
        if(colorizeIcon){
            defaultIcon.color = UIColors.UI_COMPONENT_GRAY;
        }

        var ratio:Number = iconHeight / defaultIcon.height;
        if(ratio > 0){
            defaultIcon.height = iconHeight;
            defaultIcon.width *= ratio;
        }

        toggleButton.defaultIcon = defaultIcon;
        defaultSkin = new Quad(1,1, 0xFFFFFF);
        defaultSkin.width = 35;
        defaultSkin.height = 20;
        if(ratio){
            defaultSkin.width = defaultIcon.width + 10;
        }
        toggleButton.defaultSkin = defaultSkin;

        selectedIcon = new Image(ButtonFactory.assetManager.getTexture(texture));
        if(colorizeIcon){
            selectedIcon.color = 0xFEFFFF;
        }
        selectedIcon.scale = ButtonFactory.assetManager.scaleFactor/2;
        if(ratio > 0){
            selectedIcon.height = iconHeight;
            selectedIcon.width *= ratio;
        }
        toggleButton.defaultSelectedIcon = selectedIcon;
        selectedSkin = new Quad(1, 1, 0x026edc);
        selectedSkin.width = defaultSkin.width;
        selectedSkin.height = defaultSkin.height;
        toggleButton.defaultSelectedSkin = selectedSkin;
        toggleButton.horizontalAlign = HorizontalAlign.LEFT;

        return toggleButton;
    }

    public static function createRadio(label:String, value:String, isRadio:Boolean = true, defaultIconId:String = null, selectedIconId:String = null, isColorized:Boolean = true, iconHeight:Number = 0, iconWidth:Number = 0, defaultColor:int = - 1, selectedColor:int = -1):ToggleButton{
        var radio:ToggleButton;
        if(isRadio){
            radio = new Radio();
        }else{
            radio = new ToggleButton();
        }
        var defaultIcon:Image = new Image(ButtonFactory.assetManager.getTexture(defaultIconId||"gallery_radio_default"));
        if(iconHeight > 0){
            defaultIcon.height = iconHeight;
            defaultIcon.scale = defaultIcon.scaleY;
        }else if(iconWidth > 0){
            defaultIcon.width = iconWidth;
            defaultIcon.scale = defaultIcon.scaleX;
        }else{
            defaultIcon.scale = ButtonFactory.assetManager.scaleFactor/2;
        }

        if(isColorized){
            defaultIcon.color = (defaultColor!=-1?defaultColor:UIColors.UI_COMPONENT_GRAY);
        }

        var selectedIcon:Image = new Image(ButtonFactory.assetManager.getTexture(selectedIconId||"gallery_radio_selected"));
        if(iconHeight > 0){
            selectedIcon.height = iconHeight;
            selectedIcon.scale = selectedIcon.scaleY;
        }else if(iconWidth > 0){
            selectedIcon.width = iconWidth;
            selectedIcon.scale = selectedIcon.scaleX;
        }else{
            selectedIcon.scale = ButtonFactory.assetManager.scaleFactor/2;
        }
        if(isColorized){
            selectedIcon.color = (selectedColor!=-1?selectedColor:UIColors.UI_COMPONENT_BLUE);
        }

        radio.horizontalAlign = HorizontalAlign.LEFT;
        radio.defaultIcon = defaultIcon;
        radio.defaultSelectedIcon = selectedIcon;
        radio.labelFactory = (defaultColor!=-1?GalleryLabelFactory.showByRadioGarageLabel:GalleryLabelFactory.showByRadioDefaultLabel);
        radio.labelOffsetX = 5;
        radio.iconOffsetY = 1;
        radio.label = label;
        radio.name = value;
        radio.paddingTop = -2;
        radio.paddingBottom = 2;
        radio.paddingLeft = 5;
        return radio;
    }
}
}